@@ -32,12 +32,12 @@ impl NcmApi {
         cookie_path: &str,
     ) -> Self {
         Self {
-            client: ApiClientBuilder::new()
+            client: ApiClientBuilder::new(cookie_path)
+                .cookie_path(cookie_path)
                 .cache(enable_cache)
                 .cache_exp(cache_exp)
                 .cache_clean_interval(cache_clean_interval)
                 .preserve_cookies(preserve_cookies)
-                .cookie_path(cookie_path)
                 .build()
                 .unwrap(),
         }
@@ -60,7 +60,10 @@ impl NcmApi {
     }
 
     /// Identical to search. Deprecated! Use "cloud_search" instead.
-    #[deprecated(since = "0.1.2", note = "search was rarely used. Users should instead use cloud_search")]
+    #[deprecated(
+        since = "0.1.2",
+        note = "search was rarely used. Users should instead use cloud_search"
+    )]
     pub async fn search(&self, key: &str, opt: Option<Value>) -> TResult<ApiResponse> {
         self._search(key, "search", opt).await
     }
@@ -916,16 +919,6 @@ mod tests {
         password: String,
     }
 
-    #[tokio::test(flavor = "multi_thread")]
-    async fn test_search() {
-        let api = NcmApi::default();
-        let resp = api.search("mota", None).await;
-        assert!(resp.is_ok());
-
-        let res = resp.unwrap().deserialize_to_implict();
-        assert_eq!(res.code, 200);
-    }
-
     #[tokio::test(flavor = "multi_thread")]
     async fn test_cloud_search() {
         let api = NcmApi::default();
